@@ -521,7 +521,7 @@ type CacheSlideInfo5 struct {
 	PageSize        uint32 `json:"page_size,omitempty"`     // currently 16384
 	PageStartsCount uint32 `json:"page_starts_count,omitempty"`
 	_               uint32 // padding for 64bit alignment
-	AuthValueAdd    uint64 `json:"auth_value_add,omitempty"`
+	ValueAdd        uint64 `json:"value_add,omitempty"`
 	// PageStarts      []uint16 /* len() = page_starts_count */
 }
 
@@ -532,8 +532,123 @@ func (i CacheSlideInfo5) GetPageSize() uint32 {
 	return i.PageSize
 }
 func (i CacheSlideInfo5) SlidePointer(ptr uint64) uint64 {
-	pointer := CacheSlidePointer3(ptr)
-	return i.AuthValueAdd + pointer.OffsetFromSharedCacheBase()
+	if ptr == 0 {
+		return 0
+	}
+	pointer := CacheSlidePointer5(ptr)
+	if pointer.Authenticated() {
+		return i.ValueAdd + pointer.Value()
+	}
+	return i.ValueAdd + pointer.SignExtend51()
+}
+
+// CacheSlidePointer5 struct
+//
+// ???
+type CacheSlidePointer5 uint64
+
+// SignExtend51 returns a regular pointer which needs to fit in 51-bits of value.
+// C++ RTTI uses the top bit, so we'll allow the whole top-byte
+// and the signed-extended bottom 43-bits to be fit in to 51-bits.
+func (p CacheSlidePointer5) SignExtend51() uint64 {
+	top8Bits := uint64(p & 0x007F80000000000)
+	bottom43Bits := uint64(p & 0x000007FFFFFFFFFF)
+	return (top8Bits << 13) | (((uint64)(bottom43Bits<<21) >> 21) & 0x00FFFFFFFFFFFFFF)
+}
+
+// Raw returns the chained pointer's raw uint64 value
+func (p CacheSlidePointer5) Raw() uint64 {
+	return uint64(p)
+}
+
+// Value returns the chained pointer's value
+func (p CacheSlidePointer5) Value() uint64 {
+	return types.ExtractBits(uint64(p), 0, 34)
+}
+
+func (p CacheSlidePointer5) High8() uint64 {
+	return types.ExtractBits(uint64(p), 34, 8)
+}
+
+// OffsetToNextPointer returns the offset to the next chained pointer
+func (p CacheSlidePointer5) OffsetToNextPointer() uint64 {
+	return types.ExtractBits(uint64(p), 52, 11)
+}
+
+// OffsetFromSharedCacheBase returns the chained pointer's offset from the base
+func (p CacheSlidePointer5) OffsetFromSharedCacheBase() uint64 {
+	return types.ExtractBits(uint64(p), 0, 32)
+}
+
+// DiversityData returns the chained pointer's diversity data
+func (p CacheSlidePointer5) DiversityData() uint64 {
+	return types.ExtractBits(uint64(p), 34, 16)
+}
+
+// HasAddressDiversity returns if the chained pointer has address diversity
+func (p CacheSlidePointer5) HasAddressDiversity() bool {
+	return types.ExtractBits(uint64(p), 50, 1) != 0
+}
+
+// Key returns the chained pointer's key
+func (p CacheSlidePointer5) Key() uint64 {
+	return types.ExtractBits(uint64(p), 51, 1)
+}
+
+// Authenticated returns if the chained pointer is authenticated
+func (p CacheSlidePointer5) Authenticated() bool {
+	return types.ExtractBits(uint64(p), 63, 1) != 0
+}
+
+// KeyName returns the chained pointer's key name
+func KeyNameV5(key uint64) string {
+	name := []string{"IA", "DA"}
+	if key >= 2 {
+		return "ERROR"
+	}
+	return name[key]
+}
+
+func (p CacheSlidePointer5) String() string {
+	if p.Authenticated() {
+		return fmt.Sprintf("value: %#x, next: %02x, diversity: %04x, addr_div: %t, key: %s, auth: %t",
+			p.Value(),
+			p.OffsetToNextPointer(),
+			p.DiversityData(),
+			p.HasAddressDiversity(),
+			KeyNameV5(p.Key()),
+			p.Authenticated(),
+		)
+	}
+	return fmt.Sprintf("value: %#x, next: %02x", p.Value(), p.OffsetToNextPointer())
+}
+
+func (p CacheSlidePointer5) MarshalJSON() ([]byte, error) {
+	if p.Authenticated() {
+		return json.Marshal(&struct {
+			Value               uint64 `json:"value"`
+			OffsetToNextPointer uint64 `json:"next"`
+			DiversityData       uint64 `json:"diversity"`
+			HasAddressDiversity bool   `json:"addr_div"`
+			KeyName             string `json:"key"`
+			Authenticated       bool   `json:"authenticated"`
+		}{
+			Value:               p.Value(),
+			OffsetToNextPointer: p.OffsetToNextPointer(),
+			DiversityData:       p.DiversityData(),
+			HasAddressDiversity: p.HasAddressDiversity(),
+			KeyName:             KeyNameV5(p.Key()),
+			Authenticated:       p.Authenticated(),
+		})
+	} else {
+		return json.Marshal(&struct {
+			Value               uint64 `json:"value"`
+			OffsetToNextPointer uint64 `json:"next"`
+		}{
+			Value:               p.Value(),
+			OffsetToNextPointer: p.OffsetToNextPointer(),
+		})
+	}
 }
 
 const (
